@@ -125,9 +125,9 @@ void R_init_XVector(DllInfo *info)
 	REGISTER_CCALLABLE(_get_XVector_offset);
 	REGISTER_CCALLABLE(_get_XVector_length);
 	REGISTER_CCALLABLE(_get_XVector_tag);
-	REGISTER_CCALLABLE(_cache_XRaw);
-	REGISTER_CCALLABLE(_cache_XInteger);
-	REGISTER_CCALLABLE(_cache_XDouble);
+	REGISTER_CCALLABLE(_hold_XRaw);
+	REGISTER_CCALLABLE(_hold_XInteger);
+	REGISTER_CCALLABLE(_hold_XDouble);
 	REGISTER_CCALLABLE(_new_XVector);
 	REGISTER_CCALLABLE(_new_XRaw_from_tag);
 	REGISTER_CCALLABLE(_new_XInteger_from_tag);
@@ -140,11 +140,12 @@ void R_init_XVector(DllInfo *info)
 	REGISTER_CCALLABLE(_get_XVectorList_length);
 	REGISTER_CCALLABLE(_get_XVectorList_width);
 	REGISTER_CCALLABLE(_get_XVectorList_names);
-	REGISTER_CCALLABLE(_cache_XVectorList);
-	REGISTER_CCALLABLE(_get_cachedXVectorList_length);
-	REGISTER_CCALLABLE(_get_cachedXRawList_elt);
-	REGISTER_CCALLABLE(_get_cachedXIntegerList_elt);
-	REGISTER_CCALLABLE(_get_cachedXDoubleList_elt);
+	REGISTER_CCALLABLE(_hold_XVectorList);
+	REGISTER_CCALLABLE(_get_length_from_XVectorList_holder);
+	REGISTER_CCALLABLE(_get_elt_from_XRawList_holder);
+	REGISTER_CCALLABLE(_get_elt_from_XIntegerList_holder);
+	REGISTER_CCALLABLE(_get_elt_from_XDoubleList_holder);
+	REGISTER_CCALLABLE(_get_linear_subset_from_XVectorList_holder);
 	REGISTER_CCALLABLE(_set_XVectorList_names);
 	REGISTER_CCALLABLE(_new_XRawList_from_tags);
 	REGISTER_CCALLABLE(_new_XIntegerList_from_tags);
